/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.object.exception;

import com.liferay.portal.kernel.exception.PortalException;

/**
 * @author Marco Leo
 */
public class ObjectFieldNameException extends PortalException {

	public static class MustBeginWithLowerCaseLetter
		extends ObjectFieldNameException {

		public MustBeginWithLowerCaseLetter() {
			super("The first character of a name must be a lower case letter");
		}

	}

	public static class MustBeLessThan41Characters
		extends ObjectFieldNameException {

		public MustBeLessThan41Characters() {
			super("Names must be less than 41 characters");
		}

	}

	public static class MustNotBeDuplicate extends ObjectFieldNameException {

		public MustNotBeDuplicate(String name) {
			super("Duplicate name " + name);
		}

	}

	public static class MustNotBeNull extends ObjectFieldNameException {

		public MustNotBeNull() {
			super("Name is null");
		}

	}

	public static class MustNotBeReserved extends ObjectFieldNameException {

		public MustNotBeReserved(String name) {
			super("Reserved name " + name);
		}

	}

	public static class MustOnlyContainLettersAndDigits
		extends ObjectFieldNameException {

		public MustOnlyContainLettersAndDigits() {
			super("Name must only contain letters and digits");
		}

	}

	private ObjectFieldNameException(String msg) {
		super(msg);
	}

}